<?php

return [

    /*
     * manager URL
     */
    'url' => 'manager',

    /*
     * Favicon path
     */
    'favicon' => '/assets/images/icons/favicon.ico',

    /*
     * Favicon path
     */
    'logo' => '/assets/images/logos/logo.png',

    /*
     * Home Route (eg.: logo link)
     */
    'routes' => [
        'home' => 'home'
    ],

    /*
     * Manager title and subtitle
     */
    'title'    => 'Escape',
    'subtitle' => 'Manager',
    'color' => [
      'primary' => '#8914fe',
      'secondary' => '#8914fe',
      'texts' => '#fff',
    ],

    /*
     * Views
     */
    'views' => [
        'login'    => 'manager::auth.login',
        'password' => 'manager::auth.password',
        'forgot'  => 'manager::auth.forgot',
        'register' => 'manager::auth.register',
        'home'     => 'manager::home',
        'menu'     => 'manager::partials.menu',

        'layouts' => [
            'master' => 'manager::layouts.master',
            'master_base' => 'manager::layouts.master_base',
            'email'  => 'manager::layouts.email',
        ],

        'users' => [
            'form'   => 'manager::users.form',
            'index'  => 'manager::users.index',
            'create' => 'manager::users.create',
            'edit'   => 'manager::users.edit',

            'password' => [
                'index'  => 'manager::users.password.index',
            ],
        ],

        'roles' => [
            'form'   => 'manager::roles.form',
            'index'  => 'manager::roles.index',
            'create' => 'manager::roles.create',
            'edit'   => 'manager::roles.edit',
        ],

        'partials' => [
            'breadcrumb'     => 'manager::partials.breadcrumb',
            'menu-top-right' => 'manager::partials.menu-top-right',
        ],

        'error' => [
            '404' => 'manager::error/404',
        ],

        'emails' => [
            'master'        => 'manager::emails.layouts.master',
            'firstPassword' => 'manager::emails.user.first-password',
        ],

        'medias' => [
            'index' => 'manager::medias.index',
        ],
    ],

    /*
     * Redirect page after login
     */
    'redirects' => [
        'after_login' => 'manager.home',
        'login'       => 'manager.auth.login',
        'logout'      => '/manager/auth/login',
    ],

    /*
     * Controller settings which may be overriden
     */
    'controllers' => [
        'home' => [
            'index' => 'EscapeWork\Manager\Http\Controllers\HomeController@index',
        ],

        'auth' => [
            'index'  => 'EscapeWork\Manager\Http\Controllers\Auth\LoginController@index',
            'login'  => 'EscapeWork\Manager\Http\Controllers\Auth\LoginController@login',
            'logout' => 'EscapeWork\Manager\Http\Controllers\Auth\LoginController@logout',

            'password' => [
                'forgot' => 'EscapeWork\Manager\Http\Controllers\Auth\PasswordController@forgot', // tela para informar email
                'send'  => 'EscapeWork\Manager\Http\Controllers\Auth\PasswordController@send',  // envia o link
                'index' => 'EscapeWork\Manager\Http\Controllers\Auth\PasswordController@index', // tela pra digitar nova senha
                'reset' => 'EscapeWork\Manager\Http\Controllers\Auth\PasswordController@reset', // resetando no banco,

            ],
        ],

        'users' => [
            'password' => [
                'index'  => 'EscapeWork\Manager\Http\Controllers\UserPasswordController@index',
                'update' => 'EscapeWork\Manager\Http\Controllers\UserPasswordController@update',
            ],
        ],

        'MediasController' => 'EscapeWork\Manager\Http\Controllers\MediasController',
        'UsersController'  => 'EscapeWork\Manager\Http\Controllers\UsersController',
        'RolesController'  => 'EscapeWork\Manager\Http\Controllers\RolesController',
    ],

    /*
    |--------------------------------------------------------------------------
    | Pages/Roles configurations
    |--------------------------------------------------------------------------
    */

    'permissions' => [
        'on' => true,

        'pages' => [
            // 'news' => [
            //     'title'   => 'Notícias', // apenas um exemplo
            //     'actions' => [], // ex: create, read, update, delete, etc
            // ],
        ],
    ],

    /*
    |--------------------------------------------------------------------------
    | Mídias que serão utilizadas com a página padrão de administração de mídias
    |--------------------------------------------------------------------------
    */
    'videos' => false,
    'medias' => [
        'news' => [
            'model'            => 'App\Models\News',
            'title'            => 'Notícias',
            'route'            => 'manager.news.index',
            'field'            => 'title',
            'session_back_url' => 'news.url',
        ],

        'abouts' => [
            'model'            => 'App\Models\Abouts',
            'title'            => 'Informações Institucionais',
            'route'            => 'manager.abouts.index',
            'field'            => 'title',
            'session_back_url' => 'abouts.url',
        ],

        'products' => [
            'model'            => 'App\Models\Products',
            'title'            => 'Produtos',
            'route'            => 'manager.products.index',
            'field'            => 'title',
            'session_back_url' => 'products.url',
        ],
    ],
];
