# escape.manager

Manager da Escape para ser instalado com o Laravel.

## Versões

| **Laravel** | **Manager** |
|-------------|-------------|
| 5.6         | 4.0         |
| 5.6         | 3.0         |
| 5.5         | 2.9         |
| 5.4         | 2.8         |
| 5.4         | 2.7         |
| 5.3         | 2.6         |
| 5.3         | 2.5         |
| 5.2         | 2.4         |
| 5.2         | 2.3         |
| 5.1         | 2.2         |
| 5.0         | 2.0 - 2.1   |
| 4.2         | 1.0         |
| 4.1         | 0.9         |
| 4.0         | 0.1 - 0.8   |

## Instalação

Adicione no seu `composer.json` os seguintes itens:

```javascript
    "require": {
        "escapework/manager": "4.2.*"
    },

    "repositories": [
        {
            "type": "composer",
            "url": "https://packages.escape.ppg.br"
        }
    ],
```

E depois execute:

```sh
$ composer update
```

## Configurando

**OBS**: Antes de executar o comando abaixo a base de dados local deve estar configurada.

Execute o seguinte comando:

```
$ php artisan manager:configure
```

Caso seja a primeira vez que o comando é executado, ele vai te pedir informações para criação do usuário administrador. Em ambiente local, sempre utilizamos as seguintes credenciais:

* Nome: Escape
* E-mail: `web@escape.ppg.br`
* Senha: `ninjasdaholanda`

Agora, a URL `seudominio.dev/manager` já está disponível para acesso.

***

## Templates de CRUD

Existem diversos cadastros já prontos para se utilizar e não ter que ficar refazendo trabalhos.

Para ver os cadastros disponíveis, digite o seguinte comando no terminal:

```
$ php artisan manager:crud:template
```

As opções disponíveis são as seguintes:

| Template        | Descrição                                                     | Uso                                               |
|-----------------|---------------------------------------------------------------|---------------------------------------------------|
| users           | Cadastro de usuários                                          | php artisan manager:crud:template users           |
| downloads       | Cadastro de downloads                                         | php artisan manager:crud:template downloads       |
| events          | Cadastro de eventos                                           | php artisan manager:crud:template events          |
| banners         | Cadastro de banners                                           | php artisan manager:crud:template banners         |
| categories      | Cadastro de categorias                                        | php artisan manager:crud:template categories      |
| products        | Cadastro de produtos                                          | php artisan manager:crud:template products        |
| partners        | Cadastro de parceiros                                         | php artisan manager:crud:template partners        |
| clients         | Cadastro de clientes                                          | php artisan manager:crud:template clients         |
| dashboard       | boilerplate de uma dashboard (com login e etc)                | php artisan manager:crud:template dashboard       |
| subscribers     | boilerplate de um cadastro de subscribers                     | php artisan manager:crud:template subscribers     |
| leads           | boilerplate de um cadastro de leads                           | php artisan manager:crud:template leads           |
| posts           | boilerplate de um cadastro de posts                           | php artisan manager:crud:template posts           |
| contacts        | boilerplate para manager de contatos (apenas visualização)    | php artisan manager:crud:template contacts        |
| images          | CRUD para upload de imagens (pra usar com o editor do Medium) | php artisan manager:crud:template images          |
| news            | boilerplate de um cadastro de notícias                        | php artisan manager:crud:template news            |
| infos           | CRUD para informações gerais do site                          | php artisan manager:crud:template infos           |
| stores          | CRUD para cadastro lojas - Onde encontrar                     | php artisan manager:crud:template stores          |
| collection      | CRUD para cadastro de coleção, com categorias e produtos      | php artisan manager:crud:template collection      |
| representatives | CRUD para cadastro de representantes                          | php artisan manager:crud:template representatives |
| services        | CRUD para cadastro de serviços                                | php artisan manager:crud:template services        |
| applications    | CRUD para cadastro de trabalhe conosco (envio de currículos)  | php artisan manager:crud:template applications    |

**Importante:** Estes templates são apenas uma base, você deve analisar e fazer os ajustes necessários nos cadastros. É muito importante que você entenda como isso funciona.

**Importante 2:** Em alguns casos, pode ser que algo esteja quebrado devido a uma atualização do Laravel. Nesse caso, verifique o porquê de estar quebrando e faça os ajustes necessários.

## Utilização

### Novas rotas

Todas as novas rotas devem ficar no arquivo `routes/manager.php`.

### Templates

Qualquer nova view deve extender o layout master, da seguinte forma:

```php
@extends(config('manager.views.layouts.master'))

{{-- Caso queira adicionar novos stylesheets --}}
@section('styles')
    @parent
    <link href="{{ asset('css') }}" rel="stylesheet" type="text/css">
@stop

{{-- O conteúdo da página em si --}}
@section('content')
    Contúdo da página
@stop

{{-- Caso queira adicionar novos scripts --}}
@section('scripts')
    @parent
    <script src="{{ asset('file.js') }}" type="text/javascript"></script>
@stop
```

#### Menu

Para editar o menu, crie um template chamado `menu.blade.php` (de preferência, em uma subpasta chamada `manager` dentro da pasta de `views`.

Depois, altere a configuração `views.menu`, nas configurações do escape.manager (arquivo `config/manager.php`), passando o caminho do menu. Ex: `manager.menu`.

```php
<li class="{{ $page == 'clients' ? 'active' : null }}"><a href="{{ route('manager.clientes.index') }}">Clientes</a></li>

<li class="{{ $page == 'categories' ? 'active' : null }}"><a href="{{ route('categorias.index') }}">Categorias</a></li>
```

### Mensagens

Para exibir mensagens de notificação em seus templates, chame a view `manager::partials.messages` em seu template blade.

```
@include('manager::partials.messages')
```

### Campos de ativo/destaque e etc

Caso você tenha um campo de ativo/destaque na listagem de registros, você pode atualizá-lo facilmente utilizando um pequeno helpers em javascript.

```
    <td>
        <input type="checkbox" data-id="{{ $client->id }}" data-manager-update-checkbox="active" data-manager-update-url="{{ route('manager.clients.update', $member->id) }}" {{ $client->active ? 'checked="checked"' : null }}>
    </td>
```

É necessário declarar os atributos `data-manager-update-checkbox` com o nome do campo em questão, e o atributo `data-manager-update-url` com a rota para fazer update do registro. Obviamente que a rota registrada deve fazer o update do campo desejado.

### Atualizando ordenações

Para atualizar ordenações de registros diretamente na listagem, existe um helper também.

```
<tbody data-manager-sortable>
    @foreach ($clients as $client)
        <tr data-id="{{ $client->id }}" data-manager-sortable-url="{{ route('manager.clients.update', $client->id) }}">
            <td style="text-align: center; cursor: move; vertical-align: middle;"><span class="glyphicon glyphicon-move"></span></td>
            [...]
        </tr>
    @endforeach
</tbody>
```

Simples assim. Da mesma maneira que as atualizações checkboxes, é necessário que a rota faça o update corretamente.

### Alguns projetos utilizando o escapework/manager

* [Escape](http://www.escape.com.br)
* [Killjob](http://www.killjob.com.br)
* [ADVB](http://www.advb.com.br)
* [Assintecal](http://ww3.assintecal.org.br)
* [Brasil By Bags](http://www.brasilbybags.com)
* [ABIACAV](http://www.abiacav.org.br)
* [FCBB](http://www.fcbybrasil.com)
* [escape.quase](http://quase.escape.ppg.br)
* [Gabriel Rosa Leilões](http:://gabrielrosaleiloes.com.br)
* [Corso Como](http://www.corsocomo.com.br)
