(function() {
    window.App = window.App || {};

    var $form           = $('#form-medias'),
        $alerts         = $('.js-alert'),
        $progress       = $('.progress'),
        $fileuploadDrag = $('.js-fileupload-drag');

    // ==================================================================
    // Helper functions
    // ==================================================================
    var replaceMedia = function(media) {
        var template = $('#media-template').html();

        // adicionando o crop position
        template = template.replace('value="'+media.crop_position+'"', 'value="'+media.crop_position+'" selected="selected"');

        return template.replace(/{ (\w+) }/g, function (_, k) {
            return media[k] == null ? '' : media[k];
        });
    };

    var appendMedia = function(html) {
        $('.js-thumbnails').append(html);
    };

    var processResponseObject = function(response) {
        return appendMedia(replaceMedia(response));
    };

    var processResponseArray = function(response) {
        console.log(response);
        for (var i = 0; i < response.length; i++) {
            processResponseObject(response[i]);
        }

        App.Videos.bindLiveEvents();
    };

    // ======================================================================
    // Retrieving all medias
    // ======================================================================
    $.ajax({
        url: window.location.href,
        method: 'get',

        complete: function (jqXHR, textStatus) {
            if (jqXHR.responseJSON.length > 0) {
                $('.js-with-medias').show();
            } else {
                $('.js-no-medias').show();
            }

            return processResponseArray(jqXHR.responseJSON);
        }
    });

    $('#files').fileupload({
        singleFileUploads: false,
        multipart: true,

        progressall: function (e, data) {
            var progress = parseInt(data.loaded / data.total * 100, 10);
            $progress.find('.progress-bar').css('width', progress + '%');
        },

        dragover: function (e) {
            $fileuploadDrag.addClass('hover');
        },

        drop: function (e) {
            $fileuploadDrag.removeClass('hover');
        },

        add: function (e, data) {
            $progress.show();
            $fileuploadDrag.hide();
            data.submit();
        },

        done: function(result, textStatus, jqXHR) {
            $('.js-with-medias').show();
            $('.js-no-medias').hide();
        },

        complete: function(response) {
            $progress.hide();
            $fileuploadDrag.show();

            return processResponseArray(response.responseJSON);
        },

        error: function (jqXHR, textStatus, errorThrown) {
            $alerts.show().html('');

            for (var i = 0; i < jqXHR.responseJSON.files.length; i++) {
                $alerts.append(jqXHR.responseJSON.files[i]);
            }
        }
    });

    $('.medias').on('dragleave', function (e) {
        e.preventDefault();

        $('.js-fileupload-drag').removeClass('hover');
    });

    // ========================================================================
    // Updating media
    // ========================================================================
    $(document).on('submit', '.js-form-media-update', function (e) {
        var $parent, $this, $btn, id;
        e.preventDefault();

        $this   = $(this);
        $btn    = $this.find('.js-btn-submit');

        $.ajax({
            type: 'POST',
            url: $this.prop('action'),
            data: $this.serialize(),

            beforeSend: function() {
                $btn.prop('disabled', true);
            }
        })
            .always(function() {
                $btn.prop('disabled', false);
            });
    });

    // -------------------------------------
    // Sorting thumbnails
    $('.js-thumbnails').sortable({
        update: function(e, ui) {
            var $thumbs = $('[data-media]')
              , order   = 0;

            $thumbs.each(function(e) {
                var $this = $(this)
                  , id = $this.data('id')
                  , token = $this.find('.js-form-media-update input[name="_token"]').val();

                order++;

                $.post($form.prop('action') + '/' + id, {
                    '_method': 'put',
                    '_token': token,
                    'order': order
                });
            });
        }
    });

    // -------------------------------------------------------------------------
    // formulário de vídeos
    App.Videos = {
        init: function() {
            this.fetchElements();
            this.bindUIEvents();
        },

        fetchElements: function() {
            this.$form      = $('#form-videos');
            this.$video     = this.$form.find('input[name="video"]');
            this.$btnSubmit = this.$form.find('.js-btn-submit');
            this.$modal     = $('#modal-video');
        },

        bindUIEvents: function() {
            var _this = this;

            this.$form.on('submit', function(e) {
                e.preventDefault();
                _this.store();
            });
        },

        store: function() {
            var _this = this;

            $.ajax({
                type: 'POST',
                url: _this.$form.prop('action'),
                data: _this.$form.serialize(),
                beforeSend: function() {
                    _this.$btnSubmit.prop('disabled', true);
                }
            })
                .done(function(data) {
                    processResponseArray(data);
                    _this.$btnSubmit.prop('disabled', false);
                });
        },

        bindLiveEvents: function() {
            var _this = this;

            $('.medias-list-item-video').on('click', function(e) {
                _this.openVideo($(this).data('file'));
            });

            this.$modal.on('hide.bs.modal', function() {
                _this.$modal.find('iframe').attr('src', '');
            });
        },

        openVideo: function(video) {
            this.$modal.find('iframe').attr('src', 'https://www.youtube.com/embed/' + video);
            this.$modal.modal('show');
        }
    };

    // -------------------------------------------------------------------------
    // inits
    App.Videos.init();
}).call(this);
