<?php

namespace App\Http\Controllers\App;

use App\Models\Category;
use App\Models\Product;
use App\Repositories\CategoryRepository;
use App\Repositories\ProductRepository;
use Illuminate\Http\Request;

class CollectionController extends Controller
{
    /**
     * @var App\Repositories\CategoryRepository
     */
    protected $categories;

    /**
     * @var App\Repositories\ProductRepository
     */
    protected $products;

    public function __construct(
        CategoryRepository $categories,
        ProductRepository $products)
    {
        $this->categories = $categories;
        $this->products   = $products;
    }

    public function index(
        ProductRepository $products,
        CategoryRepository $categories)
    {
        return view('app.products.index', [
            'page'       => 'collection',
            'products'   => $products->featured(),
            'categories' => $categories->actives(),
        ]);
    }

    public function all(Request $request)
    {
        return view('app.products.all', [
            'page'     => 'collection',
            'subpage'  => 'all',
            'products' => $this->products->all(),
        ]);
    }

    public function functionals()
    {
        return view('app.products.functionals', [
            'page'     => 'collection',
            'subpage'  => 'functionals',
            'products' => $this->products->functionals(),
        ]);
    }

    public function category(Category $category, Request $request)
    {
        return view('app.products.category', [
            'page'     => 'collection',
            'subpage'  => '',
            'category' => $category,
            'products' => $this->products->fromCategory($category, $request),
        ]);
    }

    public function product(Category $category, Product $product, Request $request)
    {
        return view('app.products.product', [
            'page'     => 'collection',
            'subpage'  => '',
            'category' => $category,
            'product'  => $product,
            'products' => $this->products->fromCategory($category, $request),
        ]);
    }
}
