<?php

namespace App\Http\Controllers\Manager;

use App\Models\Collection;
use App\Repositories\ProductRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;

class ProductsController extends Controller
{
    /**
     * @var App\\Repositories\ProductRepository
     */
    protected $products;

    public function __construct(ProductRepository $products)
    {
        parent::__construct();

        $this->products = $products;
    }

    public function index(Request $request)
    {
        session()->put('products.url', $request->fullUrl());

        return view('manager.products.index', [
            'products' => $this->products->manager($request),
        ]);
    }

    public function edit($id)
    {
        $product = $this->products->findOrFail($id);

        return view('manager.products.edit', [
            'product' => $product,
        ]);
    }

    public function update($id, Request $request)
    {
        $product = $this->products->findOrFail($id);
        $product->fill($request->all());
        $product->save();

        if ($request->hasFile('card')) {
            $product->uploadLogo($request->file('card'));
        }

        return response()->manager([
            'route'   => session('products.url', route('manager.products.index')),
            'message' => 'O produto <strong>'.$product->reference.'</strong> foi atualizado com sucesso',
        ]);
    }
}
