<?php

namespace App\Models;

use App\Models\Collection;
use EscapeWork\LaraMedias\Traits\Medias;
use EscapeWork\LaravelSteroids\Cacheable;
use EscapeWork\LaravelSteroids\Model;
use EscapeWork\LaravelSteroids\Presentable;
use EscapeWork\LaravelSteroids\Sluggable;
use EscapeWork\LaravelSteroids\SortableScope;

class Category extends Model
{
    /**
     * Table
     */
    protected $table = 'categories';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'collection_id',
        'category_id',
        'title',
    ];

    /**
     * Traits
     */
    use Sluggable, Presentable, Cacheable, Medias;

    /**
     * Presenter
     */
    protected $presenter = 'App\Presenters\CategoryPresenter';

    /**
     * Cacheables
     */
    protected $cacheables = [
        'categories.actives',
    ];

    public static function sync($collection_id, $title, $extra = [])
    {
        $title    = ucwords(str_replace('-', ' ', $title));
        $category = static::where('title', '=', $title)
                            ->where('collection_id', '=', $collection_id)
                            ->first();

        if (! $category) {
            $category = static::create(array_merge([
                'collection_id' => $collection_id,
                'title'         => $title,
            ], $extra));
        }

        return $category;
    }

    public static function actives()
    {
        $collection = Collection::active();

        return static::where('collection_id', '=', $collection->id)
                     ->whereNull('category_id')
                     ->get();
    }

    public function collection()
    {
        return $this->belongsTo('App\Models\Collection', 'collection_id');
    }

    public function scopeActive($query)
    {
        return $query->where('active', '=', 1);
    }

    public function scopeParent($query)
    {
        return $query->whereNull('category_id');
    }

    public function products()
    {
        return $this->hasMany('App\Models\Product', 'category_id');
    }

    public function getRouteKeyName()
    {
        return 'slug';
    }

    public static function boot()
    {
        parent::boot();
        static::addGlobalScope(new SortableScope('title'));
    }
}
