<?php

namespace App\Repositories;

use App\Models\Product;
use EscapeWork\LaravelSteroids\Repository;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\DB;

class ProductRepository extends Repository
{

    public function __construct(Product $model)
    {
        $this->model = $model;
    }

    public function manager($request)
    {
        $query = $this->model
                      ->select('products.*')
                      ->distinct()
                      ->with('medias', 'collection', 'category');

        if ($request->has('title')) {
            $query->search('title', $request->title);
        }

        if ($request->has('reference')) {
            $query->search('reference', $request->reference);
        }

        if ($request->has('category_id')) {
            $query->where('category_id', $request->category_id);
        }

        return $query->orderBy('created_at', 'desc')
                     ->paginate();
    }

    public function featured()
    {
        return $this->model
                    ->active()
                    ->featured()
                    ->random()
                    ->get();
    }

    public function fromCategory($category, $request)
    {
        $query =  $this->model
                       ->select('products.*')
                       ->with('category', 'subcategory', 'medias')
                       ->where('products.category_id', '=', $category->id)
                       ->active()
                       ->joinSubcategories();

        if ($request->has('reference')) {
            $query->search('reference', $request->reference);
        }

        return $query->orderBy('subcategories.title')
                     ->groupBy('products.reference')
                     ->get();
    }

    public function search($request)
    {
        $query = $this->model
                    ->select('products.*')
                    ->active()
                    ->joinCategories()
                    ->joinSubcategories();

        if ($request->has('search')) {
            $query->where(function($query) use($request) {
                return $query->search('products.reference', $request->search)
                             ->orWhere('products.title', 'like', '%' . $request->search . '%')
                             ->orWhere('products.description', 'like', '%' . $request->search . '%')
                             ->orWhere('categories.title', 'like', '%' . $request->search . '%');
            });
        }

        return $query->orderBy('subcategories.title')
                     ->groupBy('products.reference')
                     ->take(20)
                     ->get();
    }

    public function random()
    {
        return $this->model->active()->random()->groupBy('reference')->get();
    }

    public function functionals()
    {
        $query =  $this->model
                       ->select('products.*')
                       ->with('category', 'subcategory', 'medias')
                       ->active()
                       ->functional()
                       ->joinSubcategories();

        return $query->orderBy('subcategories.title')
                     ->groupBy('products.reference')
                     ->get();
    }

    public function all()
    {
        $query =  $this->model
                       ->select('products.*')
                       ->with('category', 'subcategory', 'medias')
                       ->active()
                       ->joinSubcategories();

        return $query->orderBy('subcategories.title')
                     ->groupBy('products.reference')
                     ->get();
    }
}
