@extends(config('manager.views.layouts.master'))

@section('content')
    @include('manager::partials.breadcrumb', [
        'pages' => ['Notícias']
    ])

    @include('manager::partials.page-header', [
        'title' => 'Notícias',
        'link'  => [
            'route'    => route('manager.news.create'),
            'label'    => 'Inserir nova notícia',
            'btn-type' => 'primary',
        ],
    ])

    @include('manager::partials.messages')

    <form action="{{ route('manager.news.index') }}" class="form-inline well">
        <input type="text" name="title" class="form-control" value="{{ request('title') }}" placeholder="Filtrar notícias..." maxlength="255" autofocus>

        <button type="submit" class="btn btn-primary">Filtrar</button>
        <a href="{{ route('manager.news.index') }}" class="btn btn-default">Limpar filtros</a>
    </form>

    <table class="table table-bordered table-striped table-hover">
        <thead>
            <tr>
                <th width="100"></th>
                <th>Notícia</th>
                <th width="120">Data</th>
                <th width="100">Ativo</th>
                <th width="210"></th>
            </tr>
        </thead>
        <tbody>
            @foreach ($news as $new)
                <tr>
                    <td><img src="{{ $new->present->picture(100, 25, 'crop') }}" alt=""></td>
                    <td>{{ $new->title }}</td>
                    <td>{{ $new->present->date }}</td>
                    <td><input type="checkbox" data-id="{{ $new->id }}" data-manager-update-checkbox="active" data-manager-update-url="{{ route('manager.news.updateBasic', $new->id) }}" {{ $new->active ? 'checked="checked"' : null }}></td>
                    <td>
                        <div class="btn-group btn-group-sm">
                            <a href="{{ route('manager.medias.index', ['news', $new->id]) }}" class="btn btn-default" title="Fotos">
                                <span class="glyphicon glyphicon-camera"></span> fotos
                            </a>

                            <a href="{{ route('manager.news.edit', $new->id) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-pencil"></span> editar
                            </a>

                            <a href="{{ route('manager.news.destroy', $new->id) }}" class="btn btn-default" data-delete="true" title="Excluir">
                                <span class="glyphicon glyphicon-trash"></span> excluir
                            </a>
                        </div><!-- .btn-group -->
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table><!-- .table -->

    @if ($news->count() === 0)
        <h3 class="text-center">Nenhuma notícia encontrada.</h3>
    @endif

    {!! $news->appends(request()->except('page'))->render() !!}
@stop
