@extends(config('manager.views.layouts.master'))

@section('content')
    @include('manager::partials.breadcrumb', [
        'pages' => ['Onde encontrar', 'Representantes']
    ])

    @include('manager::partials.page-header', [
        'title'    => 'Representantes',
        'subtitle' => 'Onde encontrar',
        'link'  => [
            'route'    => route('manager.representatives.create'),
            'label'    => 'Inserir representante',
            'btn-type' => 'primary',
        ],
    ])

    @include('manager::partials.messages')

    <form action="{{ route('manager.representatives.index') }}" class="form-inline well">
        <input type="text" name="region" class="form-control" value="{{ request('region') }}" placeholder="Busca por região..." maxlength="255" autofocus>
        <input type="text" name="name" class="form-control" value="{{ request('name') }}" placeholder="Busca por nome..." maxlength="255">

        <button type="submit" class="btn btn-primary">Filtrar</button>
        <a href="{{ route('manager.representatives.index') }}" class="btn btn-default">Limpar filtros</a>
    </form>

    <table class="table table-bordered table-striped table-hover">
        <thead>
            <tr>
                <th>Representante</th>
                <th>Região</th>
                <th>Telefone</th>
                <th>E-mail</th>
                <th width="80">Ativo?</th>
                <th width="150">Ações</th>
            </tr>
        </thead>
        <tbody>
            @foreach ($representatives as $representative)
                <tr>
                    <td>{{ $representative->name }}</td>
                    <td>{{ $representative->region }}</td>
                    <td>{{ $representative->phone }}</td>
                    <td>{{ $representative->email }}</td>
                    <td><input type="checkbox" data-id="{{ $representative->id }}" data-manager-update-checkbox="active" data-manager-update-url="{{ route('manager.representatives.updateBasic', $representative->id) }}" {!! $representative->active ? 'checked="checked"' : null !!}></td>
                    <td>
                        <div class="btn-group btn-group-sm">
                            <a href="{{ route('manager.representatives.edit', $representative->id) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-pencil"></span> editar
                            </a>

                            <a href="{{ route('manager.representatives.destroy', $representative->id) }}" class="btn btn-default" data-delete="true" title="Excluir">
                                <span class="glyphicon glyphicon-trash"></span> excluir
                            </a>
                        </div><!-- .btn-group -->
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table><!-- .table -->

    @if ($representatives->count() === 0)
        <h3 class="text-center">Nenhum representante encontrado.</h3>
    @endif

    {!! $representatives->appends(request()->except('page'))->render() !!}
@stop
