@extends(config('manager.views.layouts.master'))

@section('content')
    @include('manager::partials.breadcrumb', [
        'pages' => ['Serviços']
    ])

    @include('manager::partials.page-header', [
        'title' => 'Serviços',
        'link'  => [
            'route'    => route('manager.services.create'),
            'label'    => 'Inserir novo serviço',
            'btn-type' => 'primary',
        ],
    ])

    @include('manager::partials.messages')

    <form action="{{ route('manager.services.index') }}" class="form-inline well">
        <input type="text" name="title" class="form-control" value="{{ request('title') }}" placeholder="Busca por nome do serviço..." maxlength="255" autofocus>

        <button type="submit" class="btn btn-primary">Filtrar</button>
        <a href="{{ route('manager.services.index') }}" class="btn btn-default">Limpar filtros</a>
    </form>

    <table class="table table-bordered table-striped table-hover">
        <thead>
            <tr>
                <th width="100"></th>
                <th>Serviço</th>
                <th width="100">Ativo</th>
                <th width="150">Ações</th>
            </tr>
        </thead>
        <tbody>
            @foreach ($services as $service)
                <tr>
                    <td><img src="{{ $service->present->picture(100, 20, 'crop') }}" alt=""></td>
                    <td>{{ $service->title }}</td>
                    <td><input type="checkbox" data-id="{{ $service->id }}" data-manager-update-checkbox="active" data-manager-update-url="{{ route('manager.services.updateBasic', $service->id) }}" {{ $service->active ? 'checked="checked"' : null }}></td>
                    <td>
                        <div class="btn-group btn-group-sm">
                            <a href="{{ route('manager.services.edit', $service->id) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-pencil"></span> editar
                            </a>

                            <a href="{{ route('manager.services.destroy', $service->id) }}" class="btn btn-default" data-delete="true" title="Excluir">
                                <span class="glyphicon glyphicon-trash"></span> excluir
                            </a>
                        </div><!-- .btn-group -->
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table><!-- .table -->

    @if ($services->count() === 0)
        <h3 class="text-center">Nenhuma serviço encontrada.</h3>
    @endif

    {!! $services->appends(request()->except('page'))->render() !!}
@stop
