<?php
/*
|--------------------------------------------------------------------------
| escapework/manager routes
|--------------------------------------------------------------------------
*/

# ==================================================================
# without authentication
# ==================================================================
Route::group(['prefix' => 'auth', 'middleware' => 'manager.guest'], function()
{
    Route::get('login', ['as' => 'manager.auth.index', 'uses' => config('manager.controllers.auth.index')]);
    Route::post('login', ['as' => 'manager.auth.login', 'uses' => config('manager.controllers.auth.login')]);
    Route::get('password', ['as' => 'manager.password.index', 'uses' => config('manager.controllers.auth.password.forgot')]);
    Route::post('password/send', ['as' => 'manager.auth.password.send', 'uses' => config('manager.controllers.auth.password.send')]);
    Route::get('password/reset/{token}', ['as' => 'manager.password.reset.index', 'uses' => config('manager.controllers.auth.password.index')]);
    Route::post('password/reset', ['as' => 'manager.password.reset.update', 'uses' => config('manager.controllers.auth.password.reset')]);
});

# ==================================================================
# with authentication
# ==================================================================
Route::group(['middleware' => 'manager.authenticated'], function()
{
    # home
    Route::get('/', ['as' => 'manager.home', 'uses' => config('manager.controllers.home.index')]);

    # logout
    Route::get('logout', ['as' => 'manager.auth.logout', 'uses' => config('manager.controllers.auth.logout')]);

    # users
    Route::get('users', ['as' => 'manager.admin-users.index', 'uses' => config('manager.controllers.UsersController') . '@index']);
    Route::get('users/inserir', ['as' => 'manager.admin-users.create', 'uses' => config('manager.controllers.UsersController') . '@create']);
    Route::post('users', ['as' => 'manager.admin-users.store', 'uses' => config('manager.controllers.UsersController') . '@store']);
    Route::get('users/{id}', ['as' => 'manager.admin-users.show', 'uses' => config('manager.controllers.UsersController') . '@show']);
    Route::get('users/{id}/editar', ['as' => 'manager.admin-users.edit', 'uses' => config('manager.controllers.UsersController') . '@edit']);
    Route::put('users/{id}', ['as' => 'manager.admin-users.update', 'uses' => config('manager.controllers.UsersController') . '@update']);
    Route::delete('users/{id}', ['as' => 'manager.admin-users.destroy', 'uses' => config('manager.controllers.UsersController') . '@destroy']);

    # update password
    Route::get('password/update', ['as' => 'manager.users.passwod.index', 'uses' => config('manager.controllers.users.password.index')]);
    Route::put('password/update', ['as' => 'manager.users.passwod.update', 'uses' => config('manager.controllers.users.password.update')]);

    # roles
    Route::get('roles', ['as' => 'manager.roles.index', 'uses' => config('manager.controllers.RolesController') . '@index']);
    Route::get('roles/inserir', ['as' => 'manager.roles.create', 'uses' => config('manager.controllers.RolesController') . '@create']);
    Route::post('roles', ['as' => 'manager.roles.store', 'uses' => config('manager.controllers.RolesController') . '@store']);
    Route::get('roles/{id}/editar', ['as' => 'manager.roles.edit', 'uses' => config('manager.controllers.RolesController') . '@edit']);
    Route::put('roles/{id}', ['as' => 'manager.roles.update', 'uses' => config('manager.controllers.RolesController') . '@update']);
    Route::delete('roles/{id}', ['as' => 'manager.roles.destroy', 'uses' => config('manager.controllers.RolesController') . '@destroy']);

    # tela de mídias
    Route::group(['middleware' => 'manager.mediable'], function() {
        Route::get('medias/{table}/{model_id}', ['as' => 'manager.medias.index', 'uses' => config('manager.controllers.MediasController') . '@index']);
        Route::post('medias/{table}/{model_id}', ['as' => 'manager.medias.store', 'uses' => config('manager.controllers.MediasController') . '@store']);
        Route::put('medias/{table}/{model_id}/{id}', ['as' => 'manager.medias.update', 'uses' => config('manager.controllers.MediasController') . '@update']);
        Route::delete('medias/{table}/{model_id}/{id}', ['as' => 'manager.medias.destroy', 'uses' => config('manager.controllers.MediasController') . '@destroy']);
        Route::delete('medias/{table}/{model_id}', ['as' => 'manager.medias.destroyAll', 'uses' => config('manager.controllers.MediasController') . '@destroyAll']);
    });

    # logs
    Route::get('logs', ['as' => 'manager.logs.index', 'uses' => 'Rap2hpoutre\LaravelLogViewer\LogViewerController@index']);

    # rotinas
    Route::get('rotinas', ['as' => 'manager.routines.index', 'uses' => 'EscapeWork\Manager\Http\Controllers\RoutinesController@index']);
    Route::post('rotinas/executar', ['as' => 'manager.routines.execute', 'uses' => 'EscapeWork\Manager\Http\Controllers\RoutinesController@execute']);

    Route::get('analytics/visitors', ['as' => 'manager.analytics.visitors', 'uses' => 'EscapeWork\Manager\Http\Controllers\AnalyticsController@visitors']);
});
