<?php

namespace EscapeWork\Manager\Console;

use Symfony\Component\Console\Input\InputOption;

class ControllerMakeCommand extends GeneratorCommand
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $signature = 'manager:make:controller {model} {--singular} {--folder=}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Create a new resource controller class';

    /**
     * The type of class being generated.
     *
     * @var string
     */
    protected $type = 'Controller';

    /**
     * Get the stub file for the generator.
     *
     * @return string
     */
    protected function getStub()
    {
        if ($folder = $this->option('folder')) {
            return __DIR__ . '/../../resources/stubs/'.$folder.'/controller.stub';
        }

        return __DIR__ . '/../../resources/stubs/default/controller.stub';
    }

    /**
     * Get the default namespace for the class.
     *
     * @param  string  $rootNamespace
     * @return string
     */
    protected function getDefaultNamespace($rootNamespace)
    {
        return $rootNamespace.'\Http\Controllers\Manager';
    }

    public function replaceSpecific($stub, $name)
    {
        $stub = str_replace('{{repository}}', $this->argument('model') . 'Repository', $stub);
        $stub = str_replace('{{request}}', $this->argument('model') . 'SaveRequest', $stub);
        $stub = str_replace('{{singular}}', $this->option('singular'), $stub);

        return $stub;
    }

}
