<?php

namespace EscapeWork\Manager\Console;

use Symfony\Component\Console\Input\InputOption;
use Illuminate\Support\Str;

class ModelMakeCommand extends GeneratorCommand
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $signature = 'manager:make:model {model} {--medias} {--folder=}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Create a new Eloquent model class';

    /**
     * The type of class being generated.
     *
     * @var string
     */
    protected $type = 'Model';

    /**
     * Get the stub file for the generator.
     *
     * @return string
     */
    protected function getStub()
    {
        if ($folder = $this->option('folder')) {
            return __DIR__ . '/../../resources/stubs/'.$folder.'/model.stub';
        }

        if ($this->option('medias')) {
            return __DIR__.'/../../resources/stubs/default/model-with-medias.stub';
        }

        return __DIR__.'/../../resources/stubs/default/model.stub';
    }

    /**
     * Get the default namespace for the class.
     *
     * @param  string  $rootNamespace
     * @return string
     */
    protected function getDefaultNamespace($rootNamespace)
    {
        return $rootNamespace.'\Models';
    }

    public function replaceSpecific($stub, $name)
    {
        $table = Str::lower($this->argument('model'));
        $table = Str::plural($table);

        $stub = str_replace('{{table}}', $table, $stub);

        return $stub;
    }
}
