<?php

namespace EscapeWork\Manager\Console;

use Illuminate\Support\Str;
use Symfony\Component\Console\Input\InputOption;

class RepositoryMakeCommand extends GeneratorCommand
{

    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'manager:make:repository {model} {--folder=}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Create a new Repository class';

    /**
     * The type of class being generated.
     *
     * @var string
     */
    protected $type = 'Repository';

    /**
     * Get the stub file for the generator.
     *
     * @return string
     */
    protected function getStub()
    {
        if ($folder = $this->option('folder')) {
            return __DIR__ . '/../../resources/stubs/'.$folder.'/repository.stub';
        }

        return __DIR__.'/../../resources/stubs/default/repository.stub';
    }

    /**
     * Get the default namespace for the class.
     *
     * @param  string  $rootNamespace
     * @return string
     */
    protected function getDefaultNamespace($rootNamespace)
    {
        return $rootNamespace.'\Repositories';
    }

    public function replaceSpecific($stub, $name)
    {
        $variable = Str::lower($this->argument('model'));

        $stub = str_replace('{{model}}', $this->getNameInput(), $stub);
        $stub = str_replace('{{variable}}', $variable, $stub);

        return $stub;
    }

    public function getOptions()
    {
        return [
            ['model', null, InputOption::VALUE_REQUIRED, 'The model']
        ];
    }
}
