<?php

namespace EscapeWork\Manager\Console;

use Illuminate\Console\Command;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;
use EscapeWork\Manager\Models\User;

class UpdatePasswordCommand extends Command
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'manager:user:update-password';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Altera a senha de um determinado usuário';

    /**
     * @var EscapeWork\Manager\Models\User
     */
    protected $user;

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(User $user)
    {
        parent::__construct();

        $this->user = $user;
    }

    /**
     * Execute the console command.
     *
     * @return void
     */
    public function handle()
    {
        $user = null;

        if ($this->option('email')) {
            $user = $this->user->where('email', '=', $this->option('email'))->first();
        }

        if ($this->option('id')) {
            $user = $this->user->find($this->option('id'));
        }

        if (! $user) {
            $this->error(' -> Por favor, digite o ID ou o e-mail do usuário para podermos alterar a senha');
            $this->line('');
            $this->comment('php artisan manager:update-password sua-nova-senha [--email=web@escape.ppg.br] [--id=1]');
            return;
        }

        $user->password = $this->argument('password');
        $user->save();

        $this->info(' -> Senha alterada para o usuário ' . $user->name);
    }

    public function getArguments()
    {
        return [
            ['password', InputArgument::REQUIRED, 'A nova senha que será alterada'],
        ];
    }

    public function getOptions()
    {
        return [
            ['id',    'i', InputOption::VALUE_OPTIONAL, 'O ID do usuário'],
            ['email', 'e', InputOption::VALUE_OPTIONAL, 'O e-mail do usuário'],
        ];
    }
}
