<?php

namespace EscapeWork\Manager\Console;

use EscapeWork\Manager\Generators\SchemaParser;
use Illuminate\Console\Command;
use Illuminate\Filesystem\Filesystem;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputOption;

class ViewsMakeCommand extends Command
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $signature = 'manager:make:views {title?} {--singular=} {--variable=} {--schema=} {--folder=}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Cria as views para o CRUD';
    private $title;
    private $variable;

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(Filesystem $files)
    {
        parent::__construct();

        $this->files = $files;
    }

    public function handle()
    {
        $this->title = $this->argument('title');
        if (is_null($this->title)) {
            $this->title = $this->ask('Qual o título da página (ex.: Produtos, Serviços, Categorias)?');
        }

        $this->variable = $this->option('variable');
        if (is_null($this->variable)) {
            $this->variable = $this->ask('Qual a variável utilizada (ex.: $products, $services, $categories)?');
        }
        $this->variable = str_replace('$', null, $this->variable);

        # criando o diretorio
        $this->makeDirectory();

        # criando a index
        $this->createView('index');
        $this->createView('create');
        $this->createView('edit');
        $this->createView('fields');

        $this->info('Views criadas com sucesso!');
    }

    protected function getPath()
    {
        $folder = $this->option('folder') ?: $this->variable .'s';

        return $this->laravel['path.base'] . '/resources/views/manager/' . $folder;
    }

    protected function createView($type)
    {
        $path = $this->getPath();

        $stub = $this->files->get($this->getStub($type));
        $stub = str_replace('{{variable}}', $this->variable, $stub);
        $stub = str_replace('{{title}}', $this->title, $stub);
        $stub = str_replace('{{singular}}', $this->option('singular'), $stub);
        $stub = str_replace('{{titlelower}}', strtolower($this->title), $stub);

        if ($this->files->exists("{$path}/{$type}.blade.php")) {
            $this->error("View $type já existe!");
            return;
        }

        $this->files->put(
            "{$path}/{$type}.blade.php",
            $stub
        );
    }

    protected function getStub($type)
    {
        if ($folder = $this->option('folder')) {
            return __DIR__ . '/../../resources/stubs/'.$folder.'/view-'.$type.'.stub';
        }

        return __DIR__ . '/../../resources/stubs/default/view-'.$type.'.stub';
    }

    protected function makeDirectory()
    {
        $path = $this->getPath();

        if (! $this->files->isDirectory($path)) {
            $this->files->makeDirectory($path, 0777, true, true);
        }
    }

    protected function getFields()
    {
        if ($this->option('schema')) {
            $schema = new SchemaParser($this->option('schema'));
            $view   = null;

            foreach ($schema->getFields() as $field) {
                $stub = $this->files->get($this->getStub('fields'));
                $stub = str_replace('{{variable}}', $this->variable, $stub);
                $stub = str_replace('{{field}}', $field, $stub);

                $view .= $stub;
            }

            return $view;
        }
    }

    protected function createFields()
    {
        $path = $this->getPath();

        $this->files->put(
            "{$path}/fields.blade.php",
            $this->getFields()
        );
    }
}
