<?php

namespace EscapeWork\Manager\Http\Controllers\Auth;

use EscapeWork\Manager\Http\Controllers\Controller;
use EscapeWork\Manager\Http\Requests\Password\PasswordResetRequest;
use EscapeWork\Manager\Http\Requests\Password\PasswordSendRequest;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Password;

class PasswordController extends Controller
{

    /**
     * Tela para informar o email
     */
    public function forgot()
    {
        return view('manager::auth.forgot');
    }

    /**
     * Enviando um link para refazer a senha no email da pessoa
     */
    public function send(PasswordSendRequest $request)
    {
        $response = Password::broker('manager')->sendResetLink($request->only('email'), function($m)
        {
            $m->subject('Seu lembrete de senha');
        });

        switch ($response)
        {
            case Password::RESET_LINK_SENT:
                return redirect()->back()
                                ->with('message', trans('manager::password.msg.' . $response));

            case Password::INVALID_USER:
                return redirect()->back()->with('error', trans('manager::validation.email.exists'));
        }
    }

    /**
     * Tela para refazer a senha
     */
    public function index($token)
    {
        return view('manager::auth.reset', [
            'token' => $token,
        ]);
    }

    /**
     * Resetando a senha no banco de dados
     */
    public function reset(PasswordResetRequest $request)
    {
        $credentials = $request->only(
            'email', 'password', 'password_confirmation', 'token'
        );

        $response = Password::broker('manager')->reset($credentials, function($user, $password)
        {
            $user->password = $password;
            $user->save();

            Auth::guard('manager')->login($user);
        });

        switch ($response) {
            case Password::PASSWORD_RESET:
                return redirect(route('manager.home'))
                       ->with('message', trans('manager::password.msg.' . $response));

            default:
                return redirect()->back()
                                 ->withInput($request->only('email'))
                                 ->with('error', trans('manager::password.msg.' . $response));
        }
    }
}
