<?php

namespace EscapeWork\Manager\Http\Controllers;
use Analytics;
use Spatie\Analytics\Period;
use Cache;

class HomeController extends Controller
{

    public function index()
    {
        if( config("analytics.view_id") ){

          $time = 30;
          $visitorsByDay = Cache::remember('visitorsByDay', $time, function () {
            return Analytics::performQuery(Period::days(30),'ga:sessions,ga:pageviews',['dimensions' => 'ga:date']);
          });

          $visitorsAndPageviews = Cache::remember('visitorsAndPageviews', $time, function () {
            return Analytics::performQuery(Period::days(30),'ga:sessions,ga:pageviews');
          });

          $browsers = Cache::remember('browsers', $time, function () {
            return Analytics::performQuery(Period::days(30),'ga:sessions',['dimensions'=>'ga:deviceCategory']);
          });

          $mostVisited = Cache::remember('mostVisited', $time, function () {
            return Analytics::fetchMostVisitedPages(Period::days(30),20);
          });

          $averageTime = Cache::remember('averageTime', $time, function () {
            $averageTime = Analytics::performQuery(Period::days(30),'ga:avgSessionDuration');
            return $averageTime = (object) $this->secondsToTime( $averageTime->rows[0][0] ) ;
          });
        }

        return view(config('manager.views.home'),
        [
          'visitorsByDay' => isset( $visitorsByDay ) ? $visitorsByDay : null,
          'visitorsAndPageviews' => isset($visitorsAndPageviews ) ? $visitorsAndPageviews : null,
          'browsers' => isset( $browsers ) ? $browsers : null,
          'mostVisited' => isset( $mostVisited ) ? $mostVisited : null,
          'averageTime' => isset( $averageTime ) ? $averageTime : null
        ]);
    }

    function secondsToTime($inputSeconds) {

        $secondsInAMinute = 60;
        $secondsInAnHour  = 60 * $secondsInAMinute;
        $secondsInADay    = 24 * $secondsInAnHour;

        // extract days
        $days = floor($inputSeconds / $secondsInADay);

        // extract hours
        $hourSeconds = $inputSeconds % $secondsInADay;
        $hours = floor($hourSeconds / $secondsInAnHour);

        // extract minutes
        $minuteSeconds = $hourSeconds % $secondsInAnHour;
        $minutes = floor($minuteSeconds / $secondsInAMinute);

        // extract the remaining seconds
        $remainingSeconds = $minuteSeconds % $secondsInAMinute;
        $seconds = ceil($remainingSeconds);

        // return the final array
        $obj = array(
            'd' => (int) $days,
            'h' => str_pad($hours,2,'0', STR_PAD_LEFT),
            'm' => str_pad($minutes,2,'0', STR_PAD_LEFT),
            's' => str_pad($seconds,2,'0', STR_PAD_LEFT)
        );

        return $obj;
    }

}
