<?php

namespace EscapeWork\Manager\Http\Controllers;

use EscapeWork\Manager\Http\Requests\Medias\MediaStoreRequest;
use EscapeWork\Manager\Http\Controllers\Controller;
use EscapeWork\LaraMedias\Contracts\Mediable;
use EscapeWork\LaraMedias\Models\Media;
use Illuminate\Http\Request;

class MediasController extends Controller
{

    public function __construct(Media $media)
    {
        parent::__construct();

        $this->media = $media;
    }

    public function configure()
    {
        $class       = config('manager.medias.'.request()->table.'.model');
        $this->model = new $class;
        $this->model = $this->model->findOrFail(request()->model_id);
    }

    public function index(Request $request)
    {
        $this->configure();

        if ($request->ajax()) {
            return $this->model->medias;
        }

        return view(config('manager.views.medias.index'), [
            'config'  => $request->table,
            'medias'  => $this->model->medias,
            'model'   => $this->model,
            'url'     => '/medias/' . config('medias.path'),
            'backUrl' => session(config('manager.medias.' . $request->table . '.session_back_url'), route(config('manager.medias.' . $request->table . '.route')))
        ]);
    }

    public function store(MediaStoreRequest $request)
    {
        $this->configure();

        # se for vídeo, insere o vídeo
        if ($request->type === 'video') {
            return collect([$this->model->addVideo($request->video)]);
        }

        return $this->model->uploadMultipleMedias($request->file('files'));
    }

    public function update(Request $request)
    {
        $this->configure();

        if (! $media = $this->media->findOrFail($request->id)) {
            return response([
                'error' => trans('manager-medias::controller.update.error'),
            ]);
        }

        $request->merge(['id' => $request->id]);

        $media->update($request->all());

        return response([
            'message' => trans('manager-medias::controller.update.message'),
            'id'      => $media->id
        ]);
    }

    public function destroy(Request $request)
    {
        $this->configure();

        $media = $this->media->findOrFail($request->id);

        if (! $media->delete()) {
            return redirect(route('manager.medias.index', [$request->table, $this->model->id]))
                        ->with('error', trans('manager-medias::controller.destroy.error'));
        }

        return redirect(route('manager.medias.index', [$request->table, $this->model->id]))
                    ->with('message', trans('manager-medias::controller.destroy.message'));

    }

    public function destroyAll(Request $request)
    {
        $this->configure();
        $this->model->medias->destroyAll();

        return redirect(route('manager.medias.index', [$request->table, $this->model->id]))
                    ->with('message', trans('manager-medias::controller.destroy-all.message'));
    }

}
