<?php

namespace EscapeWork\Manager\Http\Controllers;

use Auth;
use EscapeWork\Manager\Http\Requests\Role\FormRequest;
use EscapeWork\Manager\Jobs\Role\SaveRoleJob;
use EscapeWork\Manager\Repositories\PageRepository;
use EscapeWork\Manager\Repositories\RoleRepository;

class RolesController extends Controller
{
    /**
     * @var EscapeWork\Manager\Repositories\RoleRepository
     */
    protected $role;

    /**
     * @var EscapeWork\Manager\Repositories\PageRepository
     */
    protected $pages;

    public function __construct(RoleRepository $role, PageRepository $pages)
    {
        parent::__construct();

        $this->middleware('manager.hasPermission');

        $this->role  = $role;
        $this->pages = $pages;
    }

    public function index()
    {
        return view(config('manager.views.roles.index'), [
            'roles' => $this->role->visible(),
        ]);
    }

    public function create()
    {
        return view(config('manager.views.roles.create'), [
            'role'  => $this->role,
            'pages' => $this->pages,
        ]);
    }

    public function store(FormRequest $request)
    {
        $this->dispatch(new SaveRoleJob);

        return redirect(route('manager.roles.index'))
               ->with('message', trans('manager::roles.messages.store', ['role' => $request->title]));
    }

    public function edit($id)
    {
        $this->role = $this->role->findOrFail($id);
        $this->role->load('pages');

        return view(config('manager.views.roles.edit'), [
            'role'  => $this->role,
            'pages' => $this->pages,
        ]);
    }

    public function update($id, FormRequest $request)
    {
        $this->dispatch(new SaveRoleJob);

        return redirect(route('manager.roles.index'))
               ->with('message', trans('manager::roles.messages.update', ['role' => $request->title]));
    }

    /**
     * Destroying the role
     */
    public function destroy($id)
    {
        $role = $this->role->findOrFail($id);
        $role->delete();

        return redirect(route('manager.roles.index'))
            ->with('message', trans('manager::roles.messages.delete', ['role' => $role->title]));
    }
}
