<?php

namespace EscapeWork\Manager\Http\Controllers;

use Auth;
use EscapeWork\Manager\Http\Controllers\Controller;
use EscapeWork\Manager\Http\Requests\Users\UserCreateRequest;
use EscapeWork\Manager\Http\Requests\Users\UserUpdateRequest;
use EscapeWork\Manager\Jobs\Users\UserCreateJob;
use EscapeWork\Manager\Jobs\Users\UserUpdateJob;
use EscapeWork\Manager\Repositories\RoleRepository;
use EscapeWork\Manager\Repositories\UserRepository;
use Illuminate\Http\Request;

class UsersController extends Controller
{

    public function __construct(UserRepository $user, RoleRepository $role)
    {
        parent::__construct();

        $this->middleware('manager.hasPermission');

        $this->users = $user;
        $this->role  = $role;
    }

    public function index()
    {
        return view(config('manager.views.users.index'), [
            'users' => $this->users->allowed(Auth::guard('manager')->user()),
        ]);
    }

    public function create()
    {
        return view(config('manager.views.users.create'), [
            'user'  => $this->users,
            'roles' => $this->role->allowed(Auth::guard('manager')->user())->pluck('title', 'id'),
        ]);
    }

    public function store(UserCreateRequest $request)
    {
        $user = $this->dispatch(new UserCreateJob($request->all()));

        return redirect()->route('manager.admin-users.index')
               ->with('message', trans('manager::users.messages.store', ['user' => $user->name]));
    }

    public function show($id, Request $request)
    {
        if ($request->ajax()) {
            return $this->users->find($id);
        }

        return redirect()->route('manager.admin-users.index');
    }

    public function edit($id)
    {
        $user = $this->users->findOrFail($id);

        return view(config('manager.views.users.edit'), [
            'user'  => $user,
            'roles' => $this->role->allowed(Auth::guard('manager')->user())->pluck('title', 'id'),
        ]);
    }

    public function update($id, UserUpdateRequest $request)
    {
        $user = $this->dispatch(new UserUpdateJob($request->id, $request->all()));

        return redirect()->route('manager.admin-users.index')
                         ->with('message', trans('manager::users.messages.update', ['user' => $user->name]));
    }

    public function destroy($id)
    {
        $user = $this->users->findOrFail($id);

        # verificando se o usuário logado não está tentando se excluir
        if (Auth::guard('manager')->check() && $user->id == Auth::guard('manager')->user()->id) {
            return redirect()->route('manager.admin-users.index')
                    ->withErrors(trans('manager::users.error.delete'));
        }

        $user->delete();

        return redirect()->route('manager.admin-users.index')
                ->with('message', trans('manager::users.messages.delete', ['user' => $user->name]));
    }
}
