<?php

namespace EscapeWork\Manager\Http\Middleware;

use Closure;

class HasPermission
{
    /**
     * Run the request filter.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Closure  $next
     * @return mixed
     */
    public function handle($request, Closure $next)
    {
        if (config('manager.permissions.on') === false) {
            return $next($request);
        }

        $page = $this->getBasePage($request);

        if (can($page)) {
            return $next($request);
        }

        return response('Unauthorized.', 401);
    }

    private function getBasePage($request)
    {
        $baseManagerUrl  = preg_replace('/^\//', null, config('manager.url'));
        $managerSegments = explode('/', $baseManagerUrl);
        $pages           = array_diff($request->segments(), $managerSegments);
        $basePage        = array_values($pages)[0];

        return $basePage;
    }

    private function getPermissions($request)
    {
        $actions = $request->route()->getAction();

        return $actions['permissions'];
    }
}
