<?php

namespace EscapeWork\Manager\Http\Requests\Users;

use EscapeWork\Manager\Http\Requests\Request;

class UserUpdateRequest extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        $role_rules = config('manager.permissions.on') ? 'required' : 'integer';

        return [
            'role_id'  => [$role_rules],
            'name'     => ['required'],
            'email'    => ['required', 'email', 'unique' => 'unique:manager_users,email,' . $this->id],
            'password' => ['nullable', 'min:6', 'confirmed'],
        ];
    }

    public function messages()
    {
        return [
            'role_id.required'   => trans('manager::validation.role_id.required'),
            'name.required'      => trans('manager::validation.name.required'),
            'email.required'     => trans('manager::validation.email.required'),
            'email.email'        => trans('manager::validation.email.email'),
            'email.unique'       => trans('manager::validation.email.unique'),
            'password.min'       => trans('manager::validation.password.min'),
            'password.confirmed' => trans('manager::validation.password.confirmed'),
        ];
    }
}
