<?php

namespace EscapeWork\Manager\Jobs\Role;

use EscapeWork\Manager\Http\Requests\Role\FormRequest;
use EscapeWork\Manager\Jobs\Job;
use EscapeWork\Manager\Models\Role;
use EscapeWork\Manager\Models\RolePage;

class SaveRoleJob extends Job
{
    /**
     * Execute the command.
     *
     * @return void
     */
    public function handle(FormRequest $request, Role $role)
    {
        if ($request->id) {
            $role = $role->findOrFail($request->id);
        }

        $role->fill($request->all());
        $role->save();

        # deleting related pages to save them later
        $role->pages()->delete();

        # saving pages related to @role
        $pages = [];
        foreach ((array) $request->get('pages') as $page) {
            array_push($pages, new RolePage([ 'page' => $page ]));
        }

        $role->pages()->saveMany($pages);

        # salvando as actions
        $role->actions()->delete();

        collect((array) $request->get('actions'))->each(function($actions, $page) use($role) {
            foreach ($actions as $action) {
                $role->actions()->create([
                    'page'   => $page,
                    'action' => $action,
                ]);
            }
        });

        return $role;
    }
}
