<?php

namespace EscapeWork\Manager\Models;

use EscapeWork\LaravelSteroids\Model;
use Illuminate\Auth\Authenticatable;
use Illuminate\Auth\Passwords\CanResetPassword;
use Illuminate\Contracts\Auth\Authenticatable as AuthenticatableContract;
use Illuminate\Contracts\Auth\CanResetPassword as CanResetPasswordContract;
use Illuminate\Notifications\Notifiable;
use EscapeWork\Manager\Notifications\ResetPasswordNotification;

class User extends Model implements AuthenticatableContract, CanResetPasswordContract
{
    use Authenticatable, CanResetPassword, Notifiable;

    /**
     * Table
     */
    protected $table = 'manager_users';

    /**
     * The attributes excluded from the model's JSON form.
     *
     * @var array
     */
    protected $hidden = ['password'];

    /**
     * Fillable fields
     */
    public $fillable = [
        'id',
        'role_id',
        'email',
        'password',
        'name',
    ];

    public function setPasswordAttribute($password)
    {
        if ($password != '') {
            $this->attributes['password'] = \Hash::make($password);
        }
    }

    public function role()
    {
        return $this->belongsTo('EscapeWork\Manager\Models\Role', 'role_id');
    }

    public function scopeJoinRoles($query)
    {
        return $query->join('manager_roles', 'manager_users.role_id', '=', 'manager_roles.id');
    }

    public function scopeNonAdmins($query)
    {
        return $query->where('manager_roles.admin', '=', 0);
    }

    public function isAdmin()
    {
        return $this->role->admin;
    }

    public function sendPasswordResetNotification($token)
    {
        $this->notify(new ResetPasswordNotification($token));
    }
}
