<?php

namespace EscapeWork\Manager;

use EscapeWork\Manager\Repositories\UserRepository;
use EscapeWork\Manager\Repositories\RoleActionRepository;
use EscapeWork\Manager\Exceptions\UnauthorizedExcpetion;

class Permission
{
    /**
     * Array of allowed pages
     *
     * @var  array
     */
    public $pages;

    /**
     * Array of allowed specific actions in specific pages
     *
     * @var  array
     */
    public $actions;

    /**
     * Initializing the Permission Class
     *
     * @param UserRepository       $user
     * @param RoleActionRepository $roleAction
     */
    public function __construct($user)
    {
        $this->user = $user;
    }

    /**
     * Checking if the user has permission to access determined page
     * If not, throw an EscapeWork\Manager\UnauthorizedExcpetion
     *
     * @param  string $page
     * @param  string $action
     */
    public function canOrFail($page, $action = null)
    {
        if (! $roleAction = $this->can($page, $action)) {
            throw new UnauthorizedExcpetion('Você não tem permissão para acessar esta página');
        }

        return $roleAction;
    }

    /**
     * Checking if the user has permission to access determined page
     *
     * @param   string $page
     * @param   string $action
     * @return  boolean
     */
    public function can($page, $action = null)
    {
        if ($this->user && $this->user->role->all_permissions) {
            return true;
        }

        if ($action) {
            return $this->user->role->actions->hasAction($page, $action);
        }

        return $this->user->role->pages->contains('page', $page);
    }

    /**
     * Checking if the user can access unless one action on some page
     * Normaly used for menus
     *
     * @access  public
     * @param   string $page
     * @return  boolean
     */
    public function canAny($page)
    {
        return $this->can($page);
    }

    /**
     * Checking if the user is a admin
     */
    public function isAdmin()
    {
        return $this->user && $this->user->isAdmin();
    }
}
